Monthly macroeconomic indicators from the Brazilian Central Bank (Banco Central do Brasil), covering economic activity, inflation, industrial production, services, and oil production.
Format
A data frame with 560 rows and 6 variables:
- date
Date, first day of the month (YYYY-MM-DD)
- ibcbr_dessaz
IBC-Br dessazonalizado (Seasonally adjusted Central Bank Economic Activity Index). Monthly economic activity indicator that serves as a proxy for GDP, base 2002 = 100
- ipca
IPCA - Índice de Preços ao Consumidor Amplo (Broad Consumer Price Index). Monthly inflation rate in percent, official inflation measure used for monetary policy targeting
- ipi
IPI - Índice de Produção Industrial (Industrial Production Index). Measures monthly industrial production, base 2012 = 100
- oil
Produção de petróleo bruto (Crude oil production). Monthly crude oil production in thousands of barrels per day
Brazilian Central Bank (Banco Central do Brasil) https://www3.bcb.gov.br/sgspub/
Details
This dataset contains key macroeconomic indicators widely used for economic analysis and forecasting in Brazil. The data is sourced directly from the Brazilian Central Bank's Time Series Management System (SGS).
**Series codes used:**
IPCA: 433
IPI: 21859
Oil production: 1389
IBC-Br (seasonally adjusted): 24364
Examples
if (FALSE) { # has_insper_fonts()
library(ggplot2)
# Plot inflation over time using insper_timeseries
recent_data <- subset(macro_series, date >= as.Date("2020-01-01"))
insper_timeseries(recent_data, x = date, y = ipca) +
labs(
title = "Brazilian Inflation (IPCA)",
subtitle = "Monthly rate in percent (2020-present)",
y = "IPCA (%)"
)
}